using System;
using System.Collections.Generic;

using System.Drawing;
using Infragistics;
using MonoTouch.Foundation;
using MonoTouch.UIKit;

namespace ChartCustomDataAxisLabels
{
	public class GraphObject : NSObject
	{
		[Export("Territory")]
		public String Territory {get; set;}
		[Export("Cost")]
		public Double Cost {get; set;}

		public GraphObject() {}
	}

	public class ChartViewDelegate : IGChartViewDelegate
	{
		public override string ResolveLabelForAxis (IGChartView chartView, IGAxis axis, NSObject item)
		{
			if (axis.Key.Equals("xAxis"))
			{
				return ((IGCategoryPoint)item).Label;
			}
			else if (axis.Key.Equals("yAxis"))
			{
				NSNumberFormatter formatter = new NSNumberFormatter();
				formatter.NumberStyle = NSNumberFormatterStyle.Currency;
				return formatter.StringFromNumber((NSNumber)item);
			}

			return String.Empty;
		}
	}

	public partial class ChartCustomDataAxisLabelsViewController : UIViewController
	{
		IGChartView _chart = new IGChartView();
		List<NSObject> _data = new List<NSObject>();
		IGCategorySeriesDataSourceHelper _source = new IGCategorySeriesDataSourceHelper();

		public ChartCustomDataAxisLabelsViewController () {}
		
		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			this.generateData();
			_source.Data = _data.ToArray();
			_source.ValuePath = @"Cost";
			_source.LabelPath = @"Territory";

			RectangleF chartRect = this.View.Frame;
			chartRect.Inflate(-30.0f, -30.0f);
			_chart.Frame = chartRect;
			_chart.AutoresizingMask = UIViewAutoresizing.FlexibleHeight|UIViewAutoresizing.FlexibleWidth;
			_chart.Theme = IGChartGradientThemes.IGThemeDark();
			_chart.Delegate = new ChartViewDelegate();
			this.View.Add(_chart);

			_chart.AddSeries(new MonoTouch.ObjCRuntime.Class("IGColumnSeries"), "series", _source, "xAxis", "yAxis");
		}

		private void generateData()
		{
			String[] territories = new string[] {@"Canada", @"Finland", @"Holland", @"Japan", @"USA"};
			
			for (int i = 0; i < 5; i++)
			{
				GraphObject graphObject = new GraphObject();
				graphObject.Territory = territories[i];
				graphObject.Cost = new Random(i).Next(100000);
				_data.Add(graphObject);
			}
		}
	}
}

